# kuws
Kieran's useful web scripts

install using:
__*comming soon to pypi*__

or download the source with:
`git clone https://github.com/Descent098/kuws`

There is inline documentation and ~~readthedocs~~ official documentation (comming soon)

# Official Documentation
There is some readthedocs documentation with examples available at:

__*comming soon*__

# Source File & Folder Layout

- Classes
- Scripts
  - All 
- .whitesource
  - Configuration for automated CVE scanning utility
- main.py
- setup.py